pub enum FramePreflight<'a> {
Ready(DecodedRequest<'a>),
Rejected {
request_id: u64,
status: StatusCode,
used: u32,
},
Unusable(UnusableFrame),
}Variants
Ready(DecodedRequest<'a>)
The complete frame is validated and may proceed to semantic dispatch.
Rejected
A recoverable protocol error was written to the response port.
Unusable(UnusableFrame)
No response bytes were written and the chain must complete with used length zero.