pub enum RegionDirection {
DeviceReadable,
DeviceWritable,
}Expand description
Direction of one flattened descriptor-backed byte region.
Variants
DeviceReadable
Bytes are readable by the device and contain request data.
DeviceWritable
Bytes are writable by the device and contain response data.