pub struct BufferRecord<B> { /* private fields */ }Implementations
Sourceimpl<B> BufferRecord<B>
impl<B> BufferRecord<B>
pub fn resource(&self) -> Result<&B, DeviceStateError>
Sourcepub fn resource_mut(&mut self) -> Result<&mut B, DeviceStateError>
pub fn resource_mut(&mut self) -> Result<&mut B, DeviceStateError>
Borrow the live provider buffer for an explicit mutating operation.
The command engine remains responsible for validating the operation and any in-flight access policy before invoking the provider.
pub const fn context_id(&self) -> ObjectId
pub const fn info(&self) -> BufferInfo
pub const fn in_flight(&self) -> u32
pub const fn release_state(&self) -> ReleaseState