pub struct ChainRegion {
pub direction: RegionDirection,
pub bytes: u64,
}Expand description
Direction and length of one flattened chain region, without an address or transport identity.
Fields
direction: RegionDirectionDirection in which the device may access this region.
bytes: u64Nonzero region length in bytes.
Implementations
Sourceimpl ChainRegion
impl ChainRegion
Sourcepub const fn readable(bytes: u64) -> ChainRegion
pub const fn readable(bytes: u64) -> ChainRegion
Construct a device-readable region.
Sourcepub const fn writable(bytes: u64) -> ChainRegion
pub const fn writable(bytes: u64) -> ChainRegion
Construct a device-writable region.